clear all; clc;
%% LOADING OPTIMISED STEADY STATE VALUES

T_in = 340 ;         
I_s = 4.3965 ;      

% SS CONVs   80        75          70          65         60
y_A_in =    [0.12212   0.153905    0.13857     0.152603    0.141664] ;
F_in   =    [4.966     4.171       4.983       4.876       5.682  ] * 1e-8 ;


%% OPTIMISATION INPUTS

f1 = logspace(-6,2,500) ;
lb = [0 , 0] ;
ub = [0.7, 1] ;
ig = [0.5, 0.5] ;
optionsga = optimoptions('fmincon', 'display', 'off', 'FunctionTolerance', 1e-4) ;

%% OPTIMISATION MAX CONVERSION OF ACID

[Amp_1_mfo_FI, Amp_2_mfo_FI, fi_mfo_FI] = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)
    x = fmincon(@(x)objFUN(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)), ig,[],[],[],[],lb,ub,@(x)constraints(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)),optionsga) ;

    Amp_1_mfo_FI(j,i) = x(1) ;
    Amp_2_mfo_FI(j,i) = x(2) ;
    end    
end

[fG2aI10_mfo_FI, fG2aII10_mfo_FI, fG2star10_mfo_FI, Conv_I_mfo_FI, Conv_II_mfo_FI, Conv_III_mfo_FI, Conv_ss_mfo_FI, MF_A_in_mfo_FI, MF_out_I_mfo_FI, MF_out_II_mfo_FI, MF_out_III_mfo_FI]...
    = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)     
    [fi_mfo_FI(j,i), fG2aI10_mfo_FI(j,i), fG2aII10_mfo_FI(j,i), fG2star10_mfo_FI(j,i), Conv_I_mfo_FI(j,i), Conv_II_mfo_FI(j,i), Conv_III_mfo_FI(j,i), Conv_ss_mfo_FI(j,i), MF_A_in_mfo_FI(j,i), MF_out_I_mfo_FI(j,i), MF_out_II_mfo_FI(j,i), MF_out_III_mfo_FI(j,i)]...
            = combination3_sims(f1(1,i), Amp_1_mfo_FI(j,i), Amp_2_mfo_FI(j,i), I_s, T_in, y_A_in(j), F_in(j)) ;  
    end
end

%% TABLE AND SAVE

[C_max, x_index] = max(Conv_III_mfo_FI,[],2) ;
C_SS             = Conv_ss_mfo_FI(1:5,1) ;
MF_A_in          = MF_A_in_mfo_FI(1:5,1) ;
RI               = (1-(C_SS(1:5,1) ./ C_max(1:5,1))) * 100 ;
Frequency        = f1(1,x_index(1:5,1))' ;
Amp_F            = Amp_1_mfo_FI(1:5,x_index(1:5,1)) ;  
Amp_I            = Amp_2_mfo_FI(1:5,x_index(1:5,1)) ;
PhaseDiff        = fi_mfo_FI(1:5,x_index(1:5,1)) ;
Amp_F = Amp_F(1:5,1) ;
Amp_I = Amp_I(1:5,1) ;
PhaseDiff    = PhaseDiff(1:5,1) ;

for j = length(F_in)
    
MF_A_III_mean(j,1) = real(MF_out_III_mfo_FI(j,x_index(j))) ;

end
%%

TAB_FI = table(C_max, C_SS, RI, MF_A_III_mean, MF_A_in, Frequency, Amp_F, Amp_I, PhaseDiff) ;
save('NVARS_VALS_FI') 

%% DIAGRAMS

figure (2)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_FI,'k','LineWidth',2)
hold on
title('ASO FRF Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{T}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_FI,'k','LineWidth',2)
hold on
title('ASO FRF Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_FI,'k','LineWidth',2)
legend('Molar Flow Out and Conversion Optimised')
title('ASO Cross-Term Flow and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{T, I}(\omega,-\omega)}, /')
box on
grid

figure (3)
subplot(3,1,1)
semilogx(f1,Conv_I_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Flow Rate Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Light Intensity Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
ylim([69.5 70.5])
legend('Periodic', 'Steady State')
title('Combined Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (5)
subplot(3,1,1)
semilogx(f1,fi_mfo_FI,'k','LineWidth',1)
hold on
title('Optimal Phase Difference For Minimum Molar Flow Out')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
subplot(3,1,2)
semilogx(f1, Amp_1_mfo_FI*100, 'k', 'LineWidth',1)
hold on
semilogx(f1, Amp_2_mfo_FI*100, 'r', 'LineWidth',1)
ylim([0 5])
legend('Flow Rate Amplitude', 'Light Intensity Amplitude')
title('Optimal Amplitudes For Minimum Molar Flow Out')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid



%% FUNCTIONS

function [of] = objFUN(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1) ;
Amp_2 = x(2) ;

[~, ~, ~, ~, ~, ~, ~, ~, ~, ~, ~, MF_A_III]...
 = combination3_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (MF_A_III) ;
end
function [c, ceq] = constraints(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1) ;
Amp_2 = x(2) ;

[~, ~, ~, ~, ~, ~, Conv_III, ~, ~, ~, ~, MF_A_III]...
 = combination3_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III; Conv_III-100] ;
ceq = [] ;
end


