
%% LOADING OPTIMISED STEADY STATE VALUES

% load('SSVARS') ;
% pstn    = find(Conv_A>50 & Conv_A<70) ;
% [ConvSSmax, pstnmax] = max(Conv_A(pstn)) ;

T_in = 340 ;     %T(pstn(pstnmax)) ;
I_s = 4.3965 ;     %I(pstn(pstnmax)) ;
y_A_in = 0.0620 ;   %yAo(pstn(pstnmax)) ;
F_in   = 1.1122e-7 ; %Fin(pstn(pstnmax)) ;

%% OPTIMISATION INPUTS

f1 = logspace(-6,2,500) ;
lb = [0 , 0] ;
ub = [0.5, 1] ;
nvars = 2 ;
optionsga = optimoptions('ga', 'display', 'off', 'FunctionTolerance', 1e-3, 'MaxGenerations', 50000) ;

%% OPTIMISATION MAX CONVERSION OF ACID

[Amp_1_mfo_FI, Amp_2_mfo_FI, fi_mfo_FI] = deal(zeros(1,length(f1))) ;

for i = 1:length(f1)
x = ga(@(x)objFUN(x, I_s, T_in, y_A_in, F_in, f1(1,i)), nvars,[],[],[],[],lb,ub,[],optionsga) ;
                 
Amp_1_mfo_FI(1,i) = x(1) ;
Amp_2_mfo_FI(1,i) = x(2) ;
end    

[fG2aI10_mfo_FI, fG2aII10_mfo_FI, fG2star10_mfo_FI, Conv_I_mfo_FI, Conv_II_mfo_FI, Conv_III_mfo_FI, Conv_ss_mfo_FI, MF_A_in_mfo_FI, MF_out_I_mfo_FI, MF_out_II_mfo_FI, MF_out_III_mfo_FI]...
    = deal(zeros(1,length(fi))) ;

for i = 1:length(f1)     
[fi_mfo_FI(1,i), fG2aI10_mfo_FI(1,i), fG2aII10_mfo_FI(1,i), fG2star10_mfo_FI(1,i), Conv_I_mfo_FI(1,i), Conv_II_mfo_FI(1,i), Conv_III_mfo_FI(1,i), Conv_ss_mfo_FI(1,i), MF_A_in_mfo_FI(1,i), MF_out_I_mfo_FI(1,i), MF_out_II_mfo_FI(1,i), MF_out_III_mfo_FI(1,i)]...
        = combination3_sims(f1(1,i), Amp_1_mfo_FI(1,i), Amp_2_mfo_FI(1,i), I_s, T_in, y_A_in, F_in) ;  
end

%%
% nvars = 3 ;
% lb = [0  , 0, 0] ;
% ub = [0.5, 1, pi()] ;
% 
% [Amp_1_mfo_FI, Amp_2_mfo_FI, fi_mfo_FI] = deal(zeros(1,length(f1))) ;
% 
% for i = 1:length(f1)
% x = fmincon(@(x)objFUN1(x, I_s, T_in, y_A_in, F_in, f1(1,i)), nvars,[],[],[],[],lb,ub,[],optionsfmincon) ;
%                  
% Amp_1_mfo_FI(1,i) = x(1) ;
% Amp_2_mfo_FI(1,i) = x(2) ;
% fi_mfo_FI(1,i)    = x(3) ;
% end    
% 
% [fG2aI10_mfo_FI, fG2aII10_mfo_FI, fG2star10_mfo_FI, Conv_I_mfo_FI, Conv_II_mfo_FI, Conv_III_mfo_FI, Conv_ss_mfo_FI, MF_A_in_mfo_FI, MF_out_I_mfo_FI, MF_out_II_mfo_FI, MF_out_III_mfo_FI]...
%     = deal(zeros(1,length(fi))) ;
% 
% for i = 1:length(f1)     
% [fG2aI10_mfo_FI(1,i), fG2aII10_mfo_FI(1,i), fG2star10_mfo_FI(1,i), Conv_I_mfo_FI(1,i), Conv_II_mfo_FI(1,i), Conv_III_mfo_FI(1,i), Conv_ss_mfo_FI(1,i), MF_A_in_mfo_FI(1,i), MF_out_I_mfo_FI(1,i), MF_out_II_mfo_FI(1,i), MF_out_III_mfo_FI(1,i)]...
%         = combination33_sims(fi_mfo_FI(1,i), f1(1,i), Amp_1_mfo_FI(1,i), Amp_2_mfo_FI(1,i), I_s, T_in, y_A_in, F_in) ;  
% end

save('NVARS_VALS_FI.mat')

%% DIAGRAMS

figure (2)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_FI,'k','LineWidth',2)
hold on
title('ASO FRF Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{T}(\omefmincon,-\omefmincon)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_FI,'k','LineWidth',2)
hold on
title('ASO FRF Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omefmincon,-\omefmincon)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_FI,'k','LineWidth',2)
legend('Molar Flow Out and Conversion Optimised')
title('ASO Cross-Term Flow and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{T, I}(\omefmincon,-\omefmincon)}, /')
box on
grid

figure (3)
subplot(3,1,1)
semilogx(f1,Conv_I_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Flow Rate Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Light Intensity Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_FI,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_FI,'--','LineWidth',2)
ylim([69.5 70.5])
legend('Periodic', 'Steady State')
title('Combined Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (5)
subplot(3,1,1)
semilogx(f1,fi_mfo_FI,'k','LineWidth',1)
hold on
title('Optimal Phase Difference For Minimum Molar Flow Out')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
subplot(3,1,2)
semilogx(f1, Amp_1_mfo_FI*100, 'k', 'LineWidth',1)
hold on
semilogx(f1, Amp_2_mfo_FI*100, 'r', 'LineWidth',1)
legend('Flow Rate Amplitude', 'Light Intensity Amplitude')
title('Optimal Amplitudes For Minimum Molar Flow Out')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid



%% FUNCTIONS

function [of] = objFUN(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1) ;
Amp_2 = x(2) ;

[~, ~, ~, ~, ~, ~, ~, ~, ~, ~, ~, MF_A_III]...
 = combination3_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (MF_A_III) ;
end

function [of] = objFUN1(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1) ;
Amp_2 = x(2) ;
fi    = x(3) ;

[~, ~, ~, ~, ~, ~, ~, ~, ~, ~, MF_A_III]...
 = combination33_sims(fi, f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (MF_A_III) ;
end

