
%% OPTIMISED STEADY STATE VALUES

T_s = 340 ;         
I_s = 4.3965 ;      
y_A_in = 0.12112 ;    
F_in = 4.966e-8 ;  

%% OPTIMISATION INPUTS

f1 = logspace(-6,2,50) ;
 
%% OPTIMISATION, MOLAR FLOW OUT OBJECTIVE FUNCTION

nvars2 = 2 ;

lb2 = [0,   0] ;
ub2 = [0.7, 1] ;

optionsga = optimoptions('ga', 'FunctionTolerance', 1e-4, 'MaxGenerations', 50000) ;

[Amp_1_mfo_Fy, Amp_2_mfo_Fy] = deal(zeros(1,length(f1))) ;

for i = 1:length(f1)
    
x = ga(@(x)objFUN(x, I_s, T_s, y_A_in, F_in, f1(1,i)), nvars2,[],[],[],[],lb2,ub2,@(x)constraints(x, I_s, T_s, y_A_in, F_in, f1(1,i)),optionsga) ;
                                                                                               
Amp_1_mfo_Fy(1,i) = x(1);
Amp_2_mfo_Fy(1,i) = x(2);

end 

% FRF

[fi_mfo_Fy, fG2aI10_mfo_Fy, fG2aII10_mfo_Fy, fG2star10_mfo_Fy, Conv_I_mfo_Fy, Conv_II_mfo_Fy, Conv_III_mfo_Fy, Conv_ss_mfo_Fy, MF_A_in_mfo_Fy, MF_A_III_mean_mfo_Fy]...
    = deal(zeros(1,length(fi))) ;

for i = 1:length(f1)
    
[fi_mfo_Fy(1,i), fG2aI10_mfo_Fy(1,i), fG2aII10_mfo_Fy(1,i), fG2star10_mfo_Fy(1,i), Conv_I_mfo_Fy(1,i), Conv_II_mfo_Fy(1,i), Conv_III_mfo_Fy(1,i), Conv_ss_mfo_Fy(1,i), MF_A_in_mfo_Fy(1,i), MF_A_III_mean_mfo_Fy(1,i)]...
        = combination1_sims(f1(1,i), Amp_1_mfo_Fy(1,i), Amp_2_mfo_Fy(1,i), I_s, T_s, y_A_in, F_in) ;
    
end


%% OPTIMISATION, CONVERSION OBJECTIVE FUNCTION

% nvars2 = 3 ;
% 
% lb2 = [0,   0,  0] ;
% ub2 = [0.7, 1,  1] ;
% 
% optionsga = optimoptions('ga', 'FunctionTolerance', 1e-4, 'MaxGenerations', 50000) ;
% 
% [Amp_1_cv_Fy, Amp_2_cv_Fy, fi_cv_Fy] = deal(zeros(1,length(f1))) ;
% 
% for i = 1:length(f1)
%     
% x = ga(@(x)objFUN1(x, I_s, T_s, y_A_in, F_in, f1(1,i)), nvars2,[],[],[],[],lb2,ub2,@(x)constraints1(x, I_s, T_s, y_A_in, F_in, f1(1,i)),optionsga) ;
%                                                                                                
% Amp_1_cv_Fy(1,i) = x(1) ;
% Amp_2_cv_Fy(1,i) = x(2) ;
% fi_cv_Fy(1,i)    = x(3) * 2*pi() ;
% 
% end 
% 
% % FRF
% 
% [fG2aI10_cv_Fy, fG2aII10_cv_Fy, fG2star10_cv_Fy, Conv_I_cv_Fy, Conv_II_cv_Fy, Conv_III_cv_Fy, Conv_ss_cv_Fy, MF_A_in_cv_Fy, MF_A_III_mean_cv_Fy]...
%     = deal(zeros(1,length(fi))) ;
% 
% for i = 1:length(f1)
%     
% [fG2aI10_cv_Fy(1,i), fG2aII10_cv_Fy(1,i), fG2star10_cv_Fy(1,i), Conv_I_cv_Fy(1,i), Conv_II_cv_Fy(1,i), Conv_III_cv_Fy(1,i), Conv_ss_cv_Fy(1,i), MF_A_in_cv_Fy(1,i), MF_A_III_mean_cv_Fy(1,i)]...
%         = combination11_sims(f1(1,i), fi_cv_Fy(1,i), Amp_1_cv_Fy(1,i), Amp_2_cv_Fy(1,i), I_s, T_s, y_A_in, F_in) ;
%     
% end

%%

save('NVARS_VALS_Fy')

%% DIAGRAMS

figure (1)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('MFO - ASO FRFs')
legend('Inlet Volumetric Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('MFO - ASO FRFs')
legend('Inlet Acid Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{y_Ao}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_Fy,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('MFO - ASO Cross-Term')
legend('Flow and Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F, y_Ao}(\omega,-\omega)}, /')
box on
grid
%%
figure (2)
subplot(3,1,1)
semilogx(f1,Conv_I_mfo_Fy,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_Fy,'--','LineWidth',2)
legend('Periodic, Flow', 'Steady State')
title('MFO - Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_Fy,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_Fy,'--','LineWidth',2)
legend('Periodic, Molar Fraction', 'Steady State')
title('MFO - Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_Fy,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_Fy,'--','LineWidth',2)
legend('Periodic, Simultaneous', 'Steady State')
title('MFO - Flow and Molar Fraction Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion, %')
box on
grid
%%
figure (3)
subplot(3,1,1)
yyaxis left
semilogx(f1,unwrap(fi_mfo_Fy),'LineWidth',2)
ylabel('Phase [rad]')
box on
yyaxis right
semilogx(f1, Amp_1_mfo_Fy*100, '--k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2_mfo_Fy*100, '--r', 'LineWidth',2)
ylim([0 100])
legend('Phase Difference','Flow Amplitude', 'Molar Fraction Amplitude')
title('MFO - Optimal Periodic Variables')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid

%%
% figure (4)
% subplot(3,1,1)
% semilogx(f1,fG2aI10_cv_Fy,'k','LineWidth',2)
% yline(0,'--r','LineWidth',2) ;
% title('CV - ASO FRFs')
% legend('Inlet Volumetric Flow Rate')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{F}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,1,2)
% semilogx(f1,fG2aII10_cv_Fy,'k','LineWidth',2)
% yline(0,'--r','LineWidth',2) ;
% title('CV - ASO FRFs')
% legend('Inlet Acid Molar Fraction')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)_{y_Ao}(\omega,-\omega)}, /')
% box on
% grid
% subplot(3,1,3)
% semilogx(f1,fG2star10_cv_Fy,'k','LineWidth',2)
% yline(0,'--r','LineWidth',2) ;
% title('CV - ASO Cross-Term')
% legend('Flow and Molar Fraction')
% xlabel('frequency, rad/s')
% ylabel('\it{G^(^2^)^*_{F, y_Ao}(\omega,-\omega)}, /')
% box on
% grid
% %%
% figure (5)
% subplot(3,1,1)
% semilogx(f1,Conv_I_cv_Fy,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_cv_Fy,'--','LineWidth',2)
% legend('Periodic, Flow', 'Steady State')
% title('CV - Single Input Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,1,2)
% semilogx(f1,Conv_II_cv_Fy,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_cv_Fy,'--','LineWidth',2)
% legend('Periodic, Molar Fraction', 'Steady State')
% title('CV - Single Input Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion')
% box on
% grid
% subplot(3,1,3)
% semilogx(f1,Conv_III_cv_Fy,'k','LineWidth',2)
% hold on
% semilogx(f1,Conv_ss_cv_Fy,'--','LineWidth',2)
% legend('Periodic, Simultaneous', 'Steady State')
% title('CV - Flow and Molar Fraction Modulation')
% xlabel('frequency, rad/s')
% ylabel('Conversion, %')
% box on
% grid
% %%
% figure (6)
% subplot(3,1,1)
% yyaxis left
% semilogx(f1,unwrap(fi_cv_Fy),'LineWidth',2)
% ylabel('Phase [rad]')
% box on
% yyaxis right
% semilogx(f1, Amp_1_cv_Fy*100, '--k', 'LineWidth',2)
% hold on
% semilogx(f1, Amp_2_cv_Fy*100, '--r', 'LineWidth',2)
% ylim([0 100])
% legend('Phase Difference','Flow Amplitude', 'Molar Fraction Amplitude')
% title('CV - Optimal Periodic Variables')
% xlabel('frequency, rad/s')
% ylabel('Amplitude, %')
% box on
% grid

%% FUNCTIONS

% MFO OBJECTIVE FUNTION

function [of] = objFUN(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~, ~, ~, ~, ~, ~, Conv_III, ~, ~, MF_A_III_mean]...
 = combination1_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (- Conv_III) ;
end
function [c, ceq] = constraints(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~, ~, ~, ~, ~, ~, Conv_III, ~, ~, ~]...
 = combination1_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III, Conv_III-100] ;
ceq = [] ;
end

% CONVERSION OBJECTIVE FUNCTION

function [of] = objFUN1(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);
fi    = x(3) * 2*pi() ;

[~, ~, ~, ~, ~, Conv_III, ~, ~, ~]...
 = combination11_sims(f1, fi, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (- Conv_III) ;
end
function [c, ceq] = constraints1(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);
fi    = x(3) * 2*pi() ;

[~, ~, ~, ~, ~, Conv_III, ~, ~, ~]...
 = combination11_sims(f1, fi, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III, Conv_III-100] ;
ceq = [] ;
end
