clc; clear all;

%% Optimised steady states
nvars = 3;%4 ;
V     = 2.0E-4;  % m3,           Reactor Volume
kr    = 0.24;    % 1  ./ s,   Reaction pre-expo factor. Range = 0.001 - 0.24, dependant on light coverage. Assuming max
maxFin = kr*V;
%     y_A_in        F_in              I_s              T_in      
lb = [0.01e-6 * 10, 1.2e-12 / 1.2e-7 , 1.6 ] ;%283.15 / 273.15] ;
ub = [0.5    * 10 , maxFin  / 1.2e-7 , 5   ] ;%380.15 / 273.15 ] ;

[I_s, T_s, yAo_s, Fin_s, Tab] = ParetoFunction(nvars, lb, ub);


%% Plugging optimised variables into NFRF
% Fininding max conversion difference and highest throughput
for i = 1:length(I_s)
    
    [f1(i,:), fi(i,:), fG2aI10(i,:), fG2aII10(i,:), fG2star10(i,:), Conv_I(i,:),...
                       Conv_II(i,:), Conv_III(i,:), Conv_ss(i,:), MF_A_in(i,:), ...
                       MF_out_I(i,:), MF_out_II(i,:), MF_out_III(i,:), MF_out_ss(i,:)] ...
                     = combination4_sims(I_s(i,1), T_s(i,1), yAo_s(i,1), Fin_s(i,1)); 
      
    [MAXConv_III,ind] = max(Conv_III,[],2);  
   
    % Corresponding values to max
    f1_Co(i,1)    = f1(i,ind(i,1));
    fi_Co(i,1)    = fi(i,ind(i,1));
    MFAin_Co(i,1) = MF_A_in(i,1);
    MFAICO(i,1)   = MF_out_I(i,ind(i,1));
    MFAIICO(i,1)  = MF_out_II(i,ind(i,1));
    MFAIIICO(i,1) = MF_out_III(i,ind(i,1));
     
    % Difference in simultaneous and steady state conversions
    difConv(i,1)  = MAXConv_III(i,1) - Conv_ss(i,1);
     
end


  [maxdifconv,ind_dif]  = max(difConv);
  
%% Table  
%   % best SS values for input variables, for max conversion
%   I   = I_s(ind_dif,1);
%   T   = T_s(ind_dif,1);
%   yAo = yAo_s(ind_dif,1);
%   Fin = Fin_s(ind_dif,1);
%   f1o = f1(ind_dif,1);
%   fio = fi(ind_dif,1);
%   Conv_SS = Conv_ss(ind_dif,1);
%   Conv_si = Conv_III(ind_dif,ind(ind_dif,1));
%   
% disp('optimum input values')
% OPTI1 = table(I, T, yAo, Fin);
% OPTI2 = table(Conv_SS, real(Conv_si));
OPTI3 = table(Conv_ss(:,1), MAXConv_III, difConv, I_s, T_s, yAo_s, Fin_s, fi_Co);

%% DIAGRAMS
figure(1)
hold on;
subplot(2,2,1)
scatter(Conv_ss(:,1), difConv)
xlabel('Steady state Conversion [%]')
ylabel('Difference in Conversion, Combined [%]')
subplot(2,2,2)
scatter(Conv_ss(:,1), MFAin_Co)
xlabel('Steady state Conversion [%]')
ylabel('Molar Flow of Acid in [mol/s]')
subplot(2,2,3)
scatter(Conv_ss(:,1), MFAIIICO)
xlabel('Steady state Conversion [%]')
ylabel('Molar Flow of Acid out, Combined [mol/s]')
subplot(2,2,4)
scatter(MFAin_Co, MFAIIICO)
xlabel('Molar Flow of Acid in [mol/s]')
ylabel('Molar Flow of Acid out, Combined [mol/s]')
 %%
point = 2; % choose desired operating point from Figure 1 and OPTI3, =row number

figure (2)
subplot(3,1,1)
semilogx(f1(1,:),fG2aI10(point,:),'k','LineWidth',2)
hold on
title('ASO FRF Molar Fraction')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F_i_n}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1(1,:),fG2aII10(point,:),'k','LineWidth',2)
title('ASO FRF Light Intenstiy')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{I}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1(1,:),fG2star10(point,:),'k','LineWidth',2)
title('ASO Cross-Term Molar Fraction and Light Intensity')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{F_i_n,I}(\omega,-\omega)}, /')
box on
grid

figure (3)
subplot(3,1,1)
semilogx(f1(1,:),Conv_I(point,:),'k','LineWidth',2)
hold on
semilogx(f1(1,:),Conv_ss(point,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Molar Fraction Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1(1,:),Conv_II(point,:),'k','LineWidth',2)
hold on
semilogx(f1(1,:),Conv_ss(point,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Light Intensity Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1(1,:),Conv_III(point,:),'k','LineWidth',2)
hold on
semilogx(f1(1,:),Conv_ss(point,:),'--','LineWidth',2)
legend('Periodic', 'Steady State')
title('Combined Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid

figure (4)
semilogx(f1(1,:),fi(point,:),'k','LineWidth',2)
hold on
title('Optimal Phase Difference')
xlabel('frequency, rad/s')
ylabel('Phase [rad]')
box on
grid
