
%% LOADING OPTIMISED STEADY STATE VALUES

T_in = 340 ;         
I_s = 4.3965 ;      

% SS CONVs   80        75          70          65         60
y_A_in =    [0.12212   0.15391     0.13857     0.15260    0.14166] ;
F_in   =    [4.966     4.171       4.983       4.3876     5.682  ] * 1e-8 ;  
%% OPTIMISATION INPUTS

f1 = logspace(-6,2,500) ;
lb = [0,      0] ;
ub = [20/T_in, 0.7] ;
ig = [0.01,  0.5] ;
optionsga = optimoptions('fmincon', 'display', 'off', 'FunctionTolerance', 1e-4) ;

%% OPTIMISATION MAX CONVERSION OF ACID

[Amp_1_mfo_TF, Amp_2_mfo_TF, fi_mfo_TF] = deal(zeros(length(F_in),length(f1))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)
    x = fmincon(@(x)objFUN(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)), ig,[],[],[],[],lb,ub,@(x)constraints(x, I_s, T_in, y_A_in(j), F_in(j), f1(1,i)),optionsga) ;

    Amp_1_mfo_TF(j,i) = x(1);
    Amp_2_mfo_TF(j,i) = x(2);
    end    
end

[fG2aI10_mfo_TF, fG2aII10_mfo_TF, fG2star10_mfo_TF, Conv_I_mfo_TF, Conv_II_mfo_TF, Conv_III_mfo_TF, Conv_ss_mfo_TF, MF_A_in_mfo_TF, MF_out_I_mfo_TF, MF_out_II_mfo_TF, MF_out_III_mfo_TF]...
    = deal(zeros(length(F_in),length(fi))) ;

for j = 1:length(F_in)
    for i = 1:length(f1)     
    [fi_mfo_TF(j,i), fG2aI10_mfo_TF(j,i), fG2aII10_mfo_TF(j,i), fG2star10_mfo_TF(j,i), Conv_I_mfo_TF(j,i), Conv_II_mfo_TF(j,i), Conv_III_mfo_TF(j,i), Conv_ss_mfo_TF(j,i), MF_A_in_mfo_TF(j,i), MF_out_I_mfo_TF(j,i), MF_out_II_mfo_TF(j,i), MF_out_III_mfo_TF(j,i)]...
            = combination6_sims(f1(1,i), Amp_1_mfo_TF(j,i), Amp_2_mfo_TF(j,i),I_s, T_in, y_A_in(j), F_in(j)) ;  
    end
end

%% TABLE AND SAVE

[C_max, x_index] = max(Conv_III_mfo_TF,[],2) ;
C_SS             = Conv_ss_mfo_TF(1:5,1) ;
MF_A_in          = MF_A_in_mfo_TF(1:5,1) ;
RI               = (1-(C_SS(1:5,1) ./ C_max(1:5,1))) * 100 ;
Frequency        = f1(1,x_index(1:5,1))' ;
Amp_T            = Amp_1_mfo_TF(1:5,x_index(1:5,1)) ;  
Amp_F            = Amp_2_mfo_TF(1:5,x_index(1:5,1)) ;
PhaseDiff        = fi_mfo_TF(1:5,x_index(1:5,1)) ;
Amp_T = Amp_T(1:5,1) ;
Amp_F = Amp_F(1:5,1) ;
PhaseDiff    = PhaseDiff(1:5,1) ;

for j = length(F_in)
    
MF_A_III_mean(j,1) = real(MF_out_III_mfo_TF(j,x_index(j))) ;

end
%%

TAB_TI = table(C_max, C_SS, RI, MF_A_III_mean, MF_A_in, Frequency, Amp_T, Amp_F, PhaseDiff) ;
save('NVARS_VALS_TI') 

%% DIAGRAMS

figure (4)
subplot(3,1,1)
semilogx(f1,fG2aI10_mfo_TF,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Temperature')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{T}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,2)
semilogx(f1,fG2aII10_mfo_TF,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO FRFs')
legend('Inlet Volumetric Flow Rate')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)_{F}(\omega,-\omega)}, /')
box on
grid
subplot(3,1,3)
semilogx(f1,fG2star10_mfo_TF,'k','LineWidth',2)
yline(0,'--r','LineWidth',2) ;
title('ASO Cross-Term')
legend('Temperature and Flow')
xlabel('frequency, rad/s')
ylabel('\it{G^(^2^)^*_{T, F}(\omega,-\omega)}, /')
box on
grid
%%
figure (5)
subplot(3,1,1)
semilogx(f1,Conv_I_mfo_TF,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TF,'--','LineWidth',2)
legend('Periodic, Temperature', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,2)
semilogx(f1,Conv_II_mfo_TF,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TF,'--','LineWidth',2)
legend('Periodic, Flow', 'Steady State')
title('Single Input Modulation')
xlabel('frequency, rad/s')
ylabel('Conversion')
box on
grid
subplot(3,1,3)
semilogx(f1,Conv_III_mfo_TF,'k','LineWidth',2)
hold on
semilogx(f1,Conv_ss_mfo_TF,'--','LineWidth',2)
legend('Periodic, Simultaneous', 'Steady State')
title('Temperature and Flow')
xlabel('frequency, rad/s')
ylabel('Conversion, %')
% ylim([50 100])
box on
grid
%%
figure (6)
subplot(3,1,1)
yyaxis left
semilogx(f1,unwrap(fi_mfo_TF),'LineWidth',2)
ylabel('Phase [rad]')
box on
yyaxis right
semilogx(f1, Amp_1_mfo_TF*100, '--k', 'LineWidth',2)
hold on
semilogx(f1, Amp_2_mfo_TF*100, '--r', 'LineWidth',2)
% ylim([0 60])
legend('Phase Difference','Temperature Amplitude', 'Flow Amplitude')
title('Optimal Periodic Variables')
xlabel('frequency, rad/s')
ylabel('Amplitude, %')
box on
grid


%% FUNCTIONS

function [of] = objFUN(x, I_s,T_in,y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~, ~, ~, ~, ~, ~, ~, ~, ~, MF_A_I, ~, MF_A_III]...
 = combination6_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

of = (MF_A_I) ;
end
function [c, ceq] = constraints(x, I_s, T_in, y_A_in, F_in, f1)
Amp_1 = x(1);
Amp_2 = x(2);

[~,~, ~, ~, ~, ~, Conv_III, ~, ~, ~, ~, ~]...
 = combination6_sims(f1, Amp_1, Amp_2, I_s, T_in, y_A_in, F_in) ;

c = [-Conv_III; Conv_III-100] ;
ceq = [] ;
end


